@@ -107,7 +107,7 @@ class ProgramTester:
 	def get_command_arguments(self, solution_filename):
 		''' Read the command line arguments from the solution file and return so that
 		we can execute the program with those command line arguments'''
-		with open("solution/{}".format(solution_filename)) as f:
+		with open("./tester/solution/{}".format(solution_filename)) as f:
 			# Get the first line in the file
 			line = f.readline()
 			# And strip the "# Command arguments: " from the string
